<?php
/**
 * Plugin Name: WooCommerce Productlist - Short Description (EasyToolsWP)
 * Description: Adds the product short description under the product title in archives with settings.
 * Version: 1.3
 * Author: EasyToolsWP.com
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

// Hook into the WooCommerce loop to display the short description.
add_action( 'woocommerce_after_shop_loop_item_title', 'add_short_description_to_product_archives', 5 );

function add_short_description_to_product_archives() {
    global $product;

    if ( $product && is_a( $product, 'WC_Product' ) ) {
        // Get the short description.
        $short_description = $product->get_short_description();
        
        // Get settings from options.
        $max_words = get_option( 'wc_short_description_max_words', 20 ); // Default to 20 words if not set.
        $hide_on_related = get_option( 'wc_short_description_hide_on_related', 'no' );

        if ( $short_description ) {
            // Check if we are on a related products page and hide_on_related is set to 'yes'.
            if ( $hide_on_related == 'yes' && is_product() && isset( $GLOBALS['post']->post_type ) && $GLOBALS['post']->post_type === 'product' && wc_get_loop_prop( 'name' ) === 'related' ) {
                return;
            }

            // Strip HTML tags and limit to max words.
            $short_description_text = wp_strip_all_tags( $short_description );
            $short_description_text = wp_trim_words( $short_description_text, $max_words );

            echo '<div class="etwp-product-short-description">' . esc_html( $short_description_text ) . '</div>';
        }
    }
}

// Add settings page and settings.
add_action( 'admin_menu', 'wc_short_description_settings_page' );
add_action( 'admin_init', 'wc_short_description_settings_init' );

function wc_short_description_settings_page() {
    add_submenu_page(
        '', // Parent slug
        'Productlist Short Description', // Page title
        'Productlist Short Description', // Menu title
        'manage_options', // Capability
        'easytoolswp_pro-settings', // Menu slug
        'wc_short_description_settings_page_content' // Callback function
    );
}

function wc_short_description_settings_init() {
    // Register settings and fields.
    register_setting(
        'wc_short_description_settings_group', // Option group
        'wc_short_description_max_words', // Option name
        [
            'type' => 'integer',
            'default' => 20,
            'sanitize_callback' => 'absint'
        ]
    );

    register_setting(
        'wc_short_description_settings_group', // Option group
        'wc_short_description_hide_on_related', // Option name
        [
            'type' => 'string',
            'default' => 'no',
            'sanitize_callback' => 'sanitize_text_field'
        ]
    );

    // Add settings section.
    add_settings_section(
        'wc_short_description_settings_section', // ID
        'Productlist Short Description', // Title
        '__return_false', // Callback (not needed)
        'wc-short-description-settings' // Page
    );

    // Add max words field.
    add_settings_field(
        'wc_short_description_max_words', // ID
        'Max Words', // Title
        'wc_short_description_max_words_callback', // Callback function
        'wc-short-description-settings', // Page
        'wc_short_description_settings_section' // Section
    );

    // Add hide on related field.
    add_settings_field(
        'wc_short_description_hide_on_related', // ID
        'Hide on Related', // Title
        'wc_short_description_hide_on_related_callback', // Callback function
        'wc-short-description-settings', // Page
        'wc_short_description_settings_section' // Section
    );
}

function wc_short_description_max_words_callback() {
    $max_words = get_option( 'wc_short_description_max_words', 20 );
    echo '<input type="number" name="wc_short_description_max_words" value="' . esc_attr( $max_words ) . '" min="1" />';
}

function wc_short_description_hide_on_related_callback() {
    $hide_on_related = get_option( 'wc_short_description_hide_on_related', 'no' );
	echo '<span class="etwp-free">Unlock PRO Features with EasyToolsWP PRO - <a href="https://www.easytoolswp.com/download/pro-features/" target="_blank">Buy now</a></span>';
    echo '<span class="etwp-pro"><label><input type="checkbox" name="wc_short_description_hide_on_related" value="yes" ' . checked( $hide_on_related, 'yes', false ) . ' /> Hide on related (productpages)</label></span>';
}

function wc_short_description_settings_page_content() {
    ?>
    <div class="wrap">
        <form method="post" action="options.php">
            <?php
            settings_fields( 'wc_short_description_settings_group' );
            do_settings_sections( 'wc-short-description-settings' );
            submit_button();
            ?>
        </form>
    </div>
    <?php
}
?>